pub struct NpcMessageInfo<'a> {
pub character_name: &'a str,
pub message: &'a str,
pub timestamp: DateTime<Utc>,
}Fields
character_name: &'a strNull terminated character name of the NPC or the player character. The string is only valid for the duration of the call.
message: &'a strNull terminated string of the message said by an npc or the user character. The string is only valid for the duration of the call.
timestamp: DateTime<Utc>Time since epoch in nanoseconds. This can be used to sort messages, when they are out of order.