ExtrasInitFunc

Type Alias ExtrasInitFunc 

pub type ExtrasInitFunc = fn(Option<&str>, Option<&'static str>);
Called at startup of unofficial extras. Can be called before or after arcdps init func. Provides the account name and the version of the unofficial extras addon as parameters.