#[repr(C)]pub struct RawSquadMessageInfo {
pub channel_id: u32,
pub channel_type: ChannelType,
pub subgroup: u8,
pub is_broadcast: u8,
pub timestamp: *const u8,
pub timestamp_length: u64,
pub account_name: *const u8,
pub account_name_length: u64,
pub character_name: *const u8,
pub character_name_length: u64,
pub text: *const u8,
pub text_length: u64,
}Fields
channel_id: u32A unique identifier for the channel this chat message was sent over. Can be used to, for example, differentiate between squad messages sent to different squads
channel_type: ChannelTypeWhether the message is sent in a party or a squad. Note that messages sent to the party chat while in a squad will have the type ChannelType::Squad
subgroup: u8The subgroup the message was sent to, or 0 if it was sent to the entire squad.
is_broadcast: u8This lowest bit of this field will be set to 1 if the message is a broadcast, and 0 if it is not a broadcast. The upper bits of this field may be used in a later version and MUST NOT be interpreted
timestamp: *const u8Null terminated iso8601 formatted string denoting when this message was received by the server, e.g. “2022-07-09T11:45:24.888Z”. This is the “absolute ordering” for chat messages, however the time can potentially differ several seconds between the client and server because of latency and clock skew. The string is only valid for the duration of the call.
timestamp_length: u64does not include the null byte
account_name: *const u8Null terminated account name of the player that sent the message, including leading ‘:’. The string is only valid for the duration of the call.
account_name_length: u64does not include the null byte
character_name: *const u8Null terminated character name of the player that sent the message. The string is only valid for the duration of the call.
character_name_length: u64does not include the null byte
text: *const u8Null terminated string containing the content of the message that was sent. The string is only valid for the duration of the call.
text_length: u64does not include the null byte