pub type ImguiCallback = fn(ui: &Ui<'_>, not_character_select_or_loading: bool);Expand description
Provides a imgui::Ui object that is needed to draw anything. The second parameter is true whenever the player is not in character select, loading screens or forced cameras.